==> solr-solrj-9.0.0-sources.jar: org/apache/solr/client/solrj/request/schema/AbstractSchemaRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.solr.client.solrj.request.schema;

import org.apache.solr.client.solrj.SolrRequest;
import org.apache.solr.client.solrj.SolrResponse;
import org.apache.solr.common.params.SolrParams;

public abstract class AbstractSchemaRequest<T extends SolrResponse> extends SolrRequest<T> {
  private SolrParams params = null;

  public AbstractSchemaRequest(METHOD m, String path) {
    super(m, path);
  }

  public AbstractSchemaRequest(METHOD m, String path, SolrParams params) {
    this(m, path);
    this.params = params;
  }

  @Override
  public SolrParams getParams() {
    return params;
  }

  @Override
  public String getRequestType() {
    return SolrRequestType.ADMIN.toString();
  }
}

==> solr-solrj-9.8.0-sources.jar: org/apache/solr/client/solrj/request/schema/AbstractSchemaRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.solr.client.solrj.request.schema;

import org.apache.solr.client.solrj.SolrResponse;
import org.apache.solr.client.solrj.request.CollectionRequiringSolrRequest;
import org.apache.solr.common.params.SolrParams;

public abstract class AbstractSchemaRequest<T extends SolrResponse>
    extends CollectionRequiringSolrRequest<T> {
  private SolrParams params = null;

  public AbstractSchemaRequest(METHOD m, String path) {
    super(m, path);
  }

  public AbstractSchemaRequest(METHOD m, String path, SolrParams params) {
    this(m, path);
    this.params = params;
  }

  @Override
  public SolrParams getParams() {
    return params;
  }

  @Override
  public String getRequestType() {
    return SolrRequestType.ADMIN.toString();
  }
}
